from typing import Optional, List

import pydantic


class ODDMetadata(pydantic.BaseModel):
    dataset_list: Optional[List[str]] = None
    bucket: Optional[str]
    prefix: Optional[str]
    regex: Optional[str] = None



from typing import Optional

from oddrn_generator import Generator
from oddrn_generator.path_models import BasePathsModel
from oddrn_generator.server_models import AWSCloudModel


class GreatExpectationPathsModel(BasePathsModel):
    suites: Optional[str]
    types: Optional[str]
    runs: Optional[str]

    class Config:
        dependencies_map = {
            "suites": ("suites",),
            "types": ("suites", "types"),
            "runs": ("suites", "types", "runs"),
        }


class GreatExpectationGenerator(Generator):
    source = "greatexpectation"
    paths_model = GreatExpectationPathsModel
    server_model = AWSCloudModel



import os
from typing import Type, TypeVar

from pydantic import BaseModel, FilePath, DirectoryPath

from odd_ge_adapter.domain import Suite, RunResult
from odd_ge_adapter.storage import Storage

U = TypeVar("U", bound=BaseModel)


class LocalStorage(BaseModel, Storage):
    suites_path: DirectoryPath
    results_path: DirectoryPath

    def load_suites(self):
        yield from self._get_files(self.suites_path, Suite)

    def load_results(self):
        yield from self._get_files(self.results_path, RunResult)

    @staticmethod
    def _get_files(folder_path: DirectoryPath, cls: Type[U]):
        for filename in os.listdir(folder_path):
            file_path = os.path.join(folder_path, filename)
            with open(file_path, "r") as file:
                yield cls.parse_raw(file.read())



import asyncio
import logging
from os import path

from odd_collector_sdk.collector import Collector

from odd_ge_adapter.domain.plugin import AvailablePlugin

logging.basicConfig(
    level=logging.INFO, format="[%(asctime)s] %(levelname)s in %(module)s: %(message)s"
)

try:
    loop = asyncio.get_event_loop()

    cur_dirname = path.dirname(path.realpath(__file__))
    config_path = path.join(cur_dirname, "../collector_config.yaml")
    adapters_path = path.join(cur_dirname, "adapters")

    collector = Collector(
        config_path=config_path,
        root_package="odd_ge_adapter.adapters",
        plugins_union_type=AvailablePlugin,
    )

    loop.run_until_complete(collector.register_data_sources())

    collector.start_polling()

    asyncio.get_event_loop().run_forever()

except Exception as e:
    logging.error(e, exc_info=True)
    asyncio.get_event_loop().stop()
